Revision: 1833
http://nagiosplug.svn.sourceforge.net/nagiosplug/?rev=1833&view=rev
Author: dermoth
Date: 2007-11-23 14:06:28 -0800 (Fri, 23 Nov 2007)
Log Message:
-----------
comments and notes
Modified Paths:
--------------
nagiosplug/branches/dermoth_ntp_rework/plugins/check_ntp_peer.c
nagiosplug/branches/dermoth_ntp_rework/plugins/check_ntp_time.c
Modified: nagiosplug/branches/dermoth_ntp_rework/plugins/check_ntp_peer.c
===================================================================
--- nagiosplug/branches/dermoth_ntp_rework/plugins/check_ntp_peer.c 2007-11-23 21:47:04 UTC (rev 1832)
+++ nagiosplug/branches/dermoth_ntp_rework/plugins/check_ntp_peer.c 2007-11-23 22:06:28 UTC (rev 1833)
@@ -12,10 +12,15 @@
*
* This file contains the check_ntp_peer plugin
*
* This plugin to check ntp servers independant of any commandline
* programs or external libraries.
*
+* Use this plugin to check the health of an NTP server. It supports
+* checking the offset with the sync peer, the jitter and stratum. This
+* plugin will not check the clock offset between the local host and NTP
+* server; please use check_ntp_time for that purpose.
*
+*
* License Information:
*
* This program is free software; you can redistribute it and/or modify
@@ -592,6 +597,13 @@
printf("\n");
printf("%s\n", _("Notes:"));
+ printf(" %s\n", _("This plugin checks an NTP server independent of any commandline"));
+ printf(" %s\n\n", _("programs or external libraries."));
+ printf(" %s\n", _("Use this plugin to check the health of an NTP server. It supports"));
+ printf(" %s\n", _("checking the offset with the sync peer, the jitter and stratum. This"));
+ printf(" %s\n", _("plugin will not check the clock offset between the local host and NTP"));
+ printf(" %s\n\n", _("server; please use check_ntp_time for that purpose."));
+
printf(" %s\n", _("See:"));
printf(" %s\n", ("http://nagiosplug.sourceforge.net/developer-guidelines.html#THRESHOLDFORMAT"));
printf(" %s\n", _("for THRESHOLD format and examples."));
@@ -12,10 +12,15 @@
* This file contains the check_ntp_peer plugin
*
-* This plugin to check ntp servers independant of any commandline
+* This plugin checks an NTP server independent of any commandline
* programs or external libraries.
*
Modified: nagiosplug/branches/dermoth_ntp_rework/plugins/check_ntp_time.c
===================================================================
--- nagiosplug/branches/dermoth_ntp_rework/plugins/check_ntp_time.c 2007-11-23 21:47:04 UTC (rev 1832)
+++ nagiosplug/branches/dermoth_ntp_rework/plugins/check_ntp_time.c 2007-11-23 22:06:28 UTC (rev 1833)
@@ -12,10 +12,14 @@
*
* This file contains the check_ntp_time plugin
*
* This plugin checks the clock offset with an NTP server. It is
* independant of any commandline programs or external libraries.
*
+* If you'd rather want to monitor an NTP server, please use
+* check_ntp_peer.
*
+*
* License Information:
*
* This program is free software; you can redistribute it and/or modify
@@ -594,6 +598,12 @@
printf("\n");
printf("%s\n", _("Notes:"));
+ printf(" %s\n", _("This plugin checks the clock offset between the local host and a"));
+ printf(" %s\n", _("remote NTP server. It is independent of any commandline programs or"));
+ printf(" %s\n\n", _("external libraries."));
+ printf(" %s\n", _("If you'd rather want to monitor an NTP server, please use"));
+ printf(" %s\n\n", _("check_ntp_peer."));
+
printf(" %s\n", _("See:"));
printf(" %s\n", ("http://nagiosplug.sourceforge.net/developer-guidelines.html#THRESHOLDFORMAT"));
printf(" %s\n", _("for THRESHOLD format and examples."));
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
-------------------------------------------------------------------------
This SF.net email is sponsored by: Microsoft
Defy all challenges. Microsoft(R) Visual Studio 2005.
http://clk.atdmt.com/MRT/go/vse0120000070mrt/direct/01/
@@ -12,10 +12,14 @@
* This file contains the check_ntp_time plugin
*
-* This plugin checks the clock offset with an NTP server. It is
-* independant of any commandline programs or external libraries.
+* This plugin checks the clock offset between the local host and a
+* remote NTP server. It is independent of any commandline programs or
+* external libraries.
*
lmpx.com only provides a reader for public news (NNTP) servers. It is not
affiliated with the servers or forums shown here and is not responsible for
the content of articles, which is written by their respective authors.